﻿using RoomiezApp.Forms.EventArgsModel;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using RoomiezApp.Model;

namespace RoomiezApp.Forms.Dialogs
{
    public partial class AddTask : Form
    {
        public event EventHandler<TaskEventArgs> WantToAddTask;
        private List<Roommate> _roommates;
        private TaskEventArgs _task;
        public AddTask(List<Roommate> roommates, TaskEventArgs task)
        {
            InitializeComponent();
            _roommates = roommates;
            _task = task;
        }

        private void addButton_Click(object sender, EventArgs e)
        {
            if (titleTextBox.Text == "")
            {
                errorMessageLabel.Text = "Title is empty";
                return;
            }
            if (assigneeComboBox.SelectedIndex == -1)
            {
                errorMessageLabel.Text = "Assignee is not selected";
                return;
            }
            if (_task == null)
            {
                WantToAddTask?.Invoke(this, new TaskEventArgs(-1, titleTextBox.Text, descriptionTextBox.Text, dueDateTimePicker.Value, (Roommate)assigneeComboBox.SelectedItem, false));
            } 
            else
            {
                WantToAddTask?.Invoke(this, new TaskEventArgs(_task.Id, titleTextBox.Text, descriptionTextBox.Text, dueDateTimePicker.Value, (Roommate)assigneeComboBox.SelectedItem, _task.Done));
            }
            DialogResult = DialogResult.OK;
            this.Dispose();
        }

        private void cancelButton_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Abort;
            this.Dispose();
        }

        private void titleTextBox_TextChanged(object sender, EventArgs e)
        {
            errorMessageLabel.Text = "";
        }

        private void assigneeComboBox_SelectedValueChanged(object sender, EventArgs e)
        {
            errorMessageLabel.Text = "";
        }

        private void dueDateTimePicker_ValueChanged(object sender, EventArgs e)
        {
            errorMessageLabel.Text = "";
        }

        private void AddTask_Paint(object sender, PaintEventArgs e)
        {
            Rectangle rect = new Rectangle(0, 0, this.Width - 1, this.Height - 1);
            Pen pen = new Pen(Color.FromArgb(176, 174, 174), 1);
            e.Graphics.DrawRectangle(pen, rect);
        }

        private void initializeComboBox()
        {
            assigneeComboBox.DataSource = _roommates;
            assigneeComboBox.DisplayMember = "Name";
            assigneeComboBox.ValueMember = "Id";
            assigneeComboBox.ResetText();
        }

        private void AddTask_Load(object sender, EventArgs e)
        {
            initializeComboBox();
            errorMessageLabel.Text = "";
            if (_task != null)
            {
                addTaskLabel.Text = "Update Task";
                fillTask();
                addButton.Text = "Edit";
            }
        }

        private void fillTask()
        {
            if (_task == null)
            {
                return;
            }

            titleTextBox.Text = _task.Title;
            descriptionTextBox.Text = _task.Description;
            dueDateTimePicker.Value = _task.Deadline;
            assigneeComboBox.SelectedValue = _task.Roommate.Id;
        }
    }
}
