﻿using RoomiezApp.Database;
using RoomiezApp.Database.Manager;
using RoomiezApp.Forms.Dialogs;
using RoomiezApp.Forms.EventArgsModel;
using RoomiezApp.Model;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace RoomiezApp.Forms
{
    public partial class EditUsers : Form
    {
        private Flat _flat;
        private Roommate _user;
        private UserManager _uM;
        private FlatManager _fM;


        public EditUsers(Flat f, Roommate user, DBContext db)
        {
            InitializeComponent();
            _flat = f;
            _user = user;
            _uM = new UserManager(db);
            _fM = new FlatManager(db, _flat.Id);

            refreshFlatName();
            refreshListView(); 
            deleteUserButton.Enabled = false;
            editUserButton.Enabled = false;
        }

        private void refreshFlatName()
        {
            flatNameLabel.Text = _flat.Name;
            this.Text = _flat.Name + " | Edit Users";
            
        }

        private void EditUsers_Load(object sender, EventArgs e)
        {
            flatIDLabel.Text = _flat.Id + "";
            flatNameLabel.Text = _flat.Name;
            this.Text = _flat.Name + " | Edit Users";
        }


        private void addUserButton_Click(object sender, EventArgs e)
        {
            AddUser aU = new AddUser();
            aU.WantToAddUser += AddUserToDB;
            aU.ShowDialog();
            if (aU.DialogResult == DialogResult.OK)
            {
                refreshListView();
            }

        }

        private void roommateListView_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (roommateListView.SelectedItems.Count == 0) // Make sure at least one item is selected
            {
                deleteUserButton.Enabled = false;
                editUserButton.Enabled = false;
                return;
            }

            var selectedRoommateId = Convert.ToInt32(roommateListView.SelectedItems[0].SubItems[0].Text);

            if (selectedRoommateId == _user.Id)
            {
                deleteUserButton.Enabled = false;
                editUserButton.Enabled = true;
            }
            else
            {
                deleteUserButton.Enabled = true;
                editUserButton.Enabled = true;
            }

        }

        private void refreshListView()
        {
            roommateListView.Items.Clear();
            foreach (var roommate in _flat.Roommates)
            {
                var roommateListViewItem = new ListViewItem(roommate.Id + "");
                roommateListViewItem.SubItems.Add(roommate.Name);
                roommateListViewItem.SubItems.Add(roommate.IsHeadRoommate() ? "yes" : "no");

                roommateListView.Items.Add(roommateListViewItem);
            
            }

            if (_flat.Roommates.Count == 0)
            {
                deleteUserButton.Enabled = false;
                editUserButton.Enabled = false;
            }
        }

        private void AddUserToDB(object sender, AddRoommateEventArgs addEA)
        {
            if (sender == null)
            {
                return;
            }

            _uM.AddUser(addEA.Username, addEA.Password, addEA.IsHead, _flat.Id);
            _fM.FillFlatUsers(_flat);
            refreshListView();
        }

        private void deleteUserButton_Click(object sender, EventArgs e)
        {
            _uM.DeleteUser(Convert.ToInt32(roommateListView.SelectedItems[0].SubItems[0].Text));
            _fM.FillFlatUsers(_flat);
            refreshListView();
        }

        private void editUserButton_Click(object sender, EventArgs e)
        {
            int id = Convert.ToInt32(roommateListView.SelectedItems[0].SubItems[0].Text);
            string name = roommateListView.SelectedItems[0].SubItems[1].Text;
            bool isHead = roommateListView.SelectedItems[0].SubItems[2].Text == "yes" ? true : false;
            
            bool changeHead = Convert.ToInt32(roommateListView.SelectedItems[0].SubItems[0].Text) != _user.Id;
            EditUser eU = new EditUser(id, name, isHead, changeHead);
            eU.ChangeRoommate += editUserInDB;
            eU.ShowDialog();
        }

        private void editUserInDB(object sender, EditRoommateEventArgs rEA)
        {
            if (sender == null)
            {
                return;
            }
            _uM.EditUser(rEA.Id, rEA.Username, rEA.IsHead);
            _fM.FillFlatUsers(_flat);
            refreshListView();
        }
    }
}
