﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

using RoomiezApp.Model;

namespace RoomiezApp.Forms.MainWindowPanels
{
    public partial class Calendar : Form
    {
        private Flat _flat;
        private Roommate _user;
        private DateTime _current;
        public Calendar(Flat flat, Roommate user)
        {
            InitializeComponent();
            _flat = flat;
            _user = user;
        }

        private void Calendar_Load(object sender, EventArgs e) { 
            _current = new DateTime(DateTime.Now.Year, DateTime.Now.Month, 1);
            displayDates();
        }

        private void displayDates()
        {
            int today = -1;
            bool highlight = false;

            changeMonthLabel();

            if (DateTime.Now.Year == _current.Year && DateTime.Now.Month == _current.Month)
            {
                highlight = true;
                today = DateTime.Now.Day;
            }

            int daysCount = DateTime.DaysInMonth(_current.Year, _current.Month);
            int dayOfWeek = Convert.ToInt32(_current.DayOfWeek.ToString("d"));
            dayOfWeek = dayOfWeek == 0 ? 6 : dayOfWeek - 1;
            

            for (int i = 0; i < dayOfWeek; i++)
            {
                dayPanel.Controls.Add(new DayUC());
            }

            // GET A HASHMAP OF TASKS AND PAYMENTS DUE FOR EACH DAY

            for (int i = 1; i <= daysCount; i++)
            {
                DayUC duc = new DayUC(i);
                if (highlight && i == today)
                {
                    duc.HighlightCurrentDay();
                }

                dayPanel.Controls.Add(duc);
            }
        }

        private void changeMonthLabel()
        {
            StringBuilder label = new StringBuilder();
            label.Append(_current.ToString("MMMM"));
            if (DateTime.Now.Year != _current.Year) {
                label.Append(" " + _current.ToString("yyyy"));
            }

            monthLabel.Text = label.ToString();
        }

        private void nextMonthButton_Click(object sender, EventArgs e)
        {
            _current = _current.AddMonths(1);
            resetCalendarPanel();
            displayDates();
        }

        private void resetCalendarPanel()
        {
            dayPanel.Controls.Clear();
        }

        private void prevMonthButton_Click(object sender, EventArgs e)
        {
            _current = _current.AddMonths(-1);
            resetCalendarPanel();
            displayDates();
        }
    }
}
