﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

using RoomiezApp.Model;
using RoomiezApp.Database;
using RoomiezApp.Database.Manager;
using System.Diagnostics;

namespace RoomiezApp.Forms.MainWindowPanels
{
    public partial class Summary : Form
    {
        private Flat _flat;
        private Roommate _user;
        private DBContext _db;
        private ShoppingListManager slM;
        private FlatManager fM;
        public event EventHandler<string> NameChanged;
        public Summary(Flat flat, Roommate user, DBContext db)
        {
            _flat = flat;
            _user = user;
            _db = db;
            slM = new ShoppingListManager(db, flat.Id);
            fM = new FlatManager(db, flat.Id);
            InitializeComponent();
        }

        private void Summary_Load(object sender, EventArgs e)
        {
            fillListBox<string>(shoppingListBox, _flat.ShoppingList);
            fillListBox<Roommate>(roommateListBox, _flat.Roommates);
            fillToDoListView();
            flatNameLabel.Text = _flat.Name;
            changeFlatNameTextbox.Hide();
            if (!_user.IsHeadRoommate())
            {
                editUsersButton.Hide();
                changeFlatNameButton.Hide();
            }
        }

        private void fillListBox<T>(ListBox box, List<T> items)
        {
            box.Items.Clear();
            foreach (T item in items)
            {
                box.Items.Add(item);
            }
        }

        private void fillToDoListView()
        {
            todoListView.Items.Clear();
            var tasks = _flat.tasks.Where(t => t.Assignee.Id == _user.Id && t.Completed == false).OrderBy(t => t.Deadline).Take(10);

            foreach (var task in tasks)
            {
                var taskListViewItem = new ListViewItem(task.Title);
                var deadlineSubItem = taskListViewItem.SubItems.Add(task.GetSummaryDeadlineString());
                if (deadlineSubItem != null && deadlineSubItem.Text == "Overdue")
                {
                    taskListViewItem.ForeColor = Color.FromArgb(194, 27, 27);
                } else if (deadlineSubItem != null && deadlineSubItem.Text == "Today")
                {
                    taskListViewItem.ForeColor = Color.FromArgb(250, 129, 40);
                }
                todoListView.Items.Add(taskListViewItem);
            }
        }

        private void slAddButton_Click(object sender, EventArgs e)
        {
            string item = slTextBox.Text;
            if (string.IsNullOrWhiteSpace(item))
            {
                return;
            }

            _flat.ShoppingList.Add(item);
            shoppingListBox.Items.Add(item);
            slM.AddItem(item);
            slTextBox.Text = "";
        }

        private void slDeleteButton_Click(object sender, EventArgs e)
        {
            int itemI = shoppingListBox.SelectedIndex;
            string item = (string) shoppingListBox.SelectedItem;
            shoppingListBox.Items.Remove(_flat.ShoppingList[itemI]);
            _flat.ShoppingList.RemoveAt(itemI);
            slM.DeleteItem(item);
        }

        private void editUsersButton_Click(object sender, EventArgs e)
        {
            EditUsers eU = new EditUsers(_flat, _user, _db);
            eU.ShowDialog();
            fillListBox<Roommate>(roommateListBox, _flat.Roommates);

        }

        private void changeFlatNameTextBox_KeyPress(object sender, KeyPressEventArgs e)
        {
            if (e.KeyChar == (char) Keys.Enter)
            {
                string newName = changeFlatNameTextbox.Text;
                changeFlatNameTextbox.Hide();
                _flat.Name = newName;
                fM.ChangeName(newName);
                flatNameLabel.Text = newName;
                NameChanged?.Invoke(this, newName);
            }
        }

        private void changeFlatNameButton_Click(object sender, EventArgs e)
        {
            changeFlatNameTextbox.Show();
            changeFlatNameTextbox.Text = _flat.Name;
        }

        private void todoListView_DrawSubItem(object sender, DrawListViewSubItemEventArgs e)
        {
            var subItemText = e.SubItem.Text;

            if (subItemText == "OVERDUE")
            {
                e.SubItem.ForeColor = Color.FromArgb(194, 27, 27);
            }

            e.SubItem.Font = new Font(e.SubItem.Font.FontFamily, 8.25f, FontStyle.Regular);

        }
    }
}
