﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace RoomiezApp.Model
{
    public class Task
    {
        public int Id
        {
            get
            {
                return _id;
            }
        }

        private int _id;
        public bool Completed;
        public string Title;
        public string Description;
        public DateTime Deadline;
        public Roommate Assignee;
        private bool _done;

        public Task(int id, string name, string description, DateTime deadline, Roommate asignee, bool done)
        {
            _id = id;
            Title = name;
            Description = description;
            Deadline = deadline;
            Assignee = asignee;
            _done = done;
        }

        public void CompleteTask()
        {
            Completed = false;
        }

        public string GetSummaryDeadlineString()
        {
            TimeSpan duration = Deadline - DateTime.Now;
            int days = (int)duration.TotalDays;

            if (days < 0)
            {
                return "Overdue";
            }
            if (days == 0)
            {
                if (duration.TotalSeconds > 0)
                {
                    return "1d";
                }
                return "Today";
            }

            days += 1;

            StringBuilder dateString = new StringBuilder();

            int weeks = days / 7;
            if (weeks > 0)
            {
                dateString.Append($"{weeks}w ");
            }

            days = days % 7;
            if (days > 0)
            {
                dateString.Append($"{days}d");
            }

            return dateString.ToString().Trim();
        }
    }
}
